import QtQuick 2.6
import QtQuick.Controls 1.5
import SddmComponents 2.0

Rectangle{

    id: container
    width: 265
    height: 410

    LayoutMirroring.enabled: Qt.locale().textDirection == Qt.RightToLeft
    LayoutMirroring.childrenInherit: true

    TextConstants { id: textConstants }

    Connections {
        target: sddm

        onLoginSucceeded: {
            errorMessage.color = "#ff0000"
            errorMessage.text = textConstants.loginSucceeded
        }

        onLoginFailed: {
            errorMessage.color = "#ff0000"
            errorMessage.text = textConstants.loginFailed
        }
    }

    Background {
        anchors.fill: parent
        source: config.background
        fillMode: Image.PreserveAspectCrop

        onStatusChanged: {
            if (status == Image.Error && source != config.defaultBackground) {
                source = config.defaultBackground
            }
        }
    }

    Rectangle{
        anchors.fill: parent
        color: "transparent"
        
        Clock {
            id: clock
            anchors.centerIn: parent
            anchors.verticalCenterOffset: 0
            anchors.horizontalCenterOffset: 100 - parent.width / 3

            color: "#304121"
            timeFont.family: "Ubuntu Condensed"
            dateFont.family: "Ubuntu Condensed"
            }

        Rectangle{
            id: rec1
            width: 265
            height: 410
            color: "transparent"
            anchors.verticalCenter: parent.verticalCenter
            anchors.horizontalCenter: parent.horizontalCenter


            Image {
                source: "recuadro.png"
                anchors.horizontalCenter: rec1.horizontalCenter
                anchors.verticalCenter: rec1.verticalCenter
            }

            Column{
                id:mainColumn
                width: 245
                height: rec1.height
                spacing: 30
                anchors.verticalCenter: rec1.verticalCenter
                anchors.horizontalCenter: rec1.horizontalCenter

                Image {
                    id: logo
                    source: "logo1.png"
                    anchors.horizontalCenter: mainColumn.horizontalCenter
                } // Fin Logo

                Column{
                    id:usrandpass
                    width: 215
                    anchors.horizontalCenter: mainColumn.horizontalCenter
                    spacing: 10


                    Label{
                        text: "Usuario"
                        font.pointSize: 10
                        font.bold: true
                        color: "white"
                    }

                    TextBox{
                        id:name
                        height: 25
                        width: usrandpass.width
                        text: userModel.lastUser
                        font.pointSize: 11
                        focusColor: "#72bc44"

                        KeyNavigation.backtab: rebootButton; KeyNavigation.tab: password

                        Keys.onPressed: {
                            if (event.key === Qt.Key_Return || event.key === Qt.Key_Enter) {
                                sddm.login(name.text, password.text, session.index)
                                event.accepted = true
                            }
                        }
                    }

                    Label{
                        text: "Contraseña"
                        font.pointSize: 10
                        font.bold: true
                        color: "white"
                    }

                    PasswordBox{
                        id: password
                        height: 25
                        width: usrandpass.width
                        font.pointSize: 11
                        focusColor: "#72bc44"
                        focus: true

                        Timer {
                            interval: 200
                            running: true
                            onTriggered: password.forceActiveFocus()
                        }

                        KeyNavigation.backtab: name; KeyNavigation.tab: session

                        Keys.onPressed: {
                            if (event.key === Qt.Key_Return || event.key === Qt.Key_Enter) {
                                sddm.login(name.text, password.text, session.index)
                                event.accepted = true
                            }
                        }
                    }
                } // Fin Columna usrandpass

                Row{
                    spacing: 60
                    width: 215
                    anchors.horizontalCenter: mainColumn.horizontalCenter

                    ImageButton{
                        id: loginButton
                        source: "preferences-system-login.png"

                        onClicked: sddm.login(name.text, password.text, session.index)

                        KeyNavigation.backtab: layoutBox;
                        KeyNavigation.tab: shutdownButton
                    }

                    ImageButton{
                        id: rebootButton
                        source: "system-reboot.png"

                        onClicked: sddm.reboot()

                        KeyNavigation.backtab: shutdownButton;
                        KeyNavigation.tab: name
                    }

                    ImageButton{
                        id: shutdownButton
                        source: "system-shutdown.png"


                        onClicked: sddm.powerOff()

                        KeyNavigation.backtab: loginButton;
                        KeyNavigation.tab: rebootButton
                    }

                } // Fin Row Botones

                Row{
                    width: 215
                    anchors.horizontalCenter: mainColumn.horizontalCenter
                    spacing: 16

                    Column{
                        spacing: 5

                        Label{
                            text:"Sesión"
                            font.bold: true
                            color: "white"
                        }

                        ComboBox {
                            id: session
                            width: 110
                            height: 25
                            arrowIcon: "angle-down.png"
                            model: sessionModel
                            index: sessionModel.lastIndex

                            KeyNavigation.backtab: password; KeyNavigation.tab: layoutBox
                        }

                    }

                    Column{
                        spacing: 5
                        Label{
                            text:"Idioma"
                            font.bold: true
                            color: "white"
                        }

                        LayoutBox {
                            id: layoutBox
                            width: 88;
                            height: 25
                            arrowIcon: "angle-down.png"
                            KeyNavigation.backtab: session; KeyNavigation.tab: loginButton
                        }

                    }

                } // Fin Row Session and Layout

                Label{
                    text: "Uso Linux porque me da la gana"
                    anchors.horizontalCenter: mainColumn.horizontalCenter
                    font.bold: true
                    color: "white"
                }

            } // Fin MainColumn

        } // Fin rec1

    } // fin Rectangle

    Component.onCompleted: {
        if (name.text == "")
            name.focus = true
        else
            password.focus = true
    }

} // Fin container

